@@ -202,7 +202,7 @@ def ToList(input):
 _USED_DIRS = set()
 
 def _PyScript(env, target, source, command = "python $SOURCES", 
-                    capture=None, execute=None, tempdir=None, *args, **kwargs): 
+                    capture=None, execute=None, tempdir=None, lightweight=True, *args, **kwargs): 
     """
     A new Builder added to a scons environment which has the same syntax as Command.
     """
@@ -256,10 +256,9 @@ PyScript(targets, sources, %s) """ % repr(command)
         os.chmod(exe, 0755)
         file.close()
 
-        command = exe + " -Q"
+        if not lightweight: command = exe + " -Q"
 
     if execute: command = execute + " " + basename
-    
 
     gen = lambda source, target, env, for_signature: command_sig if for_signature else command
     return env.Command(target, source, CommandGeneratorAction(gen,{}), *args, **kwargs)
